@@ -360,7 +360,7 @@ class DreamBoothRunner():
                     repo_name = self.config.hub_model_id
 
                 print('Repo name will be: ', repo_name)
-                self.repo = Repository(self.config.model_out_dir, clone_from=repo_name)
+                self.repo = Repository(self.config.model_out_dir, clone_from=repo_name, use_auth_token=self.auth_token)
                 print('Created repo at Run.repo')
 
                 with open(os.path.join(self.config.model_out_dir, ".gitignore"), "w+") as gitignore:
